@@ -1,4 +1,4 @@
-from threedi_api_client.threedi_api_client import ThreediApiClient
+from threedi_api_client import ThreediApiClient
 
 
 def test_init_threedi_api_client_from_env_file(tmpdir):
